@@ -46,11 +46,12 @@ def blank_error_check(event):
     """
     try:
         allowed_blank = event.other_config["canbeblank"]
+        formatting_error = getattr(event, "formatting_error", "0")
         if (
             not allowed_blank
             and not event.value
             and event.value != 0
-            and event.formatting_error != "1"
+            and formatting_error != "1"
             and getattr(event, "blank_row", 0) != "1"
         ):
             return event.from_event(event, blank_error="1")
@@ -146,9 +147,7 @@ def inherit_error(stream, error_name):
             elif isinstance(event, events.EndTable):
                 error = []
             elif isinstance(event, ErrorTable):
-                yield ErrorTable.from_event(
-                    event, **{f"{error_name}_error": error}
-                )
+                yield ErrorTable.from_event(event, **{f"{error_name}_error": error})
             yield event
         except AttributeError:
             yield event
@@ -246,7 +245,7 @@ def save_errors_la(stream, la_log_dir):
     :param la_log_dir: Location to save the gathered error logs
     :return: An updated list of event objects
     """
-    start_time = f"{datetime.now():%d-%m-%Y %Hh-%Mm-%Ss}"
+    start_time = f"{datetime.now():%Y-%m-%dT%H%M%SZ}"
     for event in stream:
         try:
             if isinstance(event, ErrorTable) and (
