@@ -63,7 +63,8 @@ def blank_error_check(event):
     """
     try:
         allowed_blank = event.config_dict["canbeblank"]
-        if not allowed_blank and not event.cell and event.error != "1":
+        error = getattr(event, "error", "0")
+        if not allowed_blank and not event.cell and error != "1":
             return event.from_event(event, blank_error="1")
         else:
             return event
@@ -123,6 +124,31 @@ def create_file_match_error(event):
     return event
 
 
+@streamfilter(
+    check=type_check(events.StartTable),
+    fail_function=pass_event,
+    error_function=pass_event,
+)
+def create_extra_column_error(event):
+    """
+    Add a extra_column_error to StartTables that have more columns than the set of expected columns so these can be written to the log.txt
+
+    :param event: A filtered list of event objects of type StartTable
+    :return: An updated list of event objects
+    """
+    extra_columns = [
+        item for item in event.headers if item not in event.expected_columns
+    ]
+    if len(extra_columns) == 0:
+        return event
+    else:
+        return event.from_event(
+            event,
+            extra_column_error=f"Additional columns were found in file titled "
+            f"'{event.filename}' than those expected from schema for filetype = {event.table_name}, so these columns have been removed: {extra_columns}",
+        )
+
+
 def save_errors_la(stream, la_log_dir):
     """
     Count the error events and save them as a text file in the Local Authority Logs directory
@@ -132,7 +158,7 @@ def save_errors_la(stream, la_log_dir):
     :param la_log_dir: Location to save the gathered error logs
     :return: An updated list of event objects
     """
-    start_time = f"{datetime.now():%d-%m-%Y %Hh-%Mm-%Ss}"
+    start_time = f"{datetime.now():%Y-%m-%dT%H%M%SZ}"
     for event in stream:
         try:
             if isinstance(event, ErrorTable) and (
@@ -140,10 +166,7 @@ def save_errors_la(stream, la_log_dir):
                 and event.blank_error_count is not None
                 and event.table_name is not None
             ):
-                if (
-                    event.formatting_error_count
-                    or event.blank_error_count
-                ):
+                if event.formatting_error_count or event.blank_error_count:
                     with open(
                         f"{os.path.join(la_log_dir, event.filename)}_error_log_{start_time}.txt",
                         "a",
@@ -183,6 +206,14 @@ def save_errors_la(stream, la_log_dir):
                 ) as f:
                     f.write(match_error)
                     f.write("\n")
+            column_error = getattr(event, "extra_column_error", None)
+            if column_error:
+                with open(
+                    f"{os.path.join(la_log_dir, event.filename)}_error_log_{start_time}.txt",
+                    "a",
+                ) as f:
+                    f.write(column_error)
+                    f.write("\n")
         yield event
 
 
@@ -197,4 +228,5 @@ def log_errors(stream):
     stream = create_formatting_error_count(stream)
     stream = create_blank_error_count(stream)
     stream = create_file_match_error(stream)
+    stream = create_extra_column_error(stream)
     return stream
