@@ -21,15 +21,10 @@ def add_year_column(stream, input, la_log_dir):
         if isinstance(event, events.StartTable):
             try:
                 file_dir = event.filename
-                match = re.search(r"20\d{2}", file_dir)
-                year = match.group(0)
+                year = common.check_year(file_dir)
                 yield event.from_event(event, year=year)
             except AttributeError:
                 common.save_year_error(input, la_log_dir)
-                raise Exception(
-                    f"{event.filename} was not processed as the filename did not contain a year, "
-                    f"this error has been sent to the LA to be fixed"
-                )
         elif isinstance(event, events.EndTable):
             yield event
             year = None
@@ -49,5 +44,12 @@ def create_la_child_id(event, la_code):
     :param la_code: The 3-character LA code used to identify a local authority
     :return: An updated list of event objects
     """
-    la_child_id = f"{event.cell}_{la_code}"
+    if isinstance(event.cell, str) and event.cell[-2:] == ".0":
+        child_id = int(float(event.cell))
+    elif isinstance(event.cell, float):
+        child_id = int(event.cell)
+    else:
+        child_id = event.cell
+
+    la_child_id = f"{child_id}_{la_code}"
     yield event.from_event(event, cell=la_child_id)
