@@ -49,12 +49,10 @@ def deduplicate(s903_df, table_name, sort_order, dedup):
     """
     Sorts and removes duplicate records from merged files following schema
     """
-    if table_name in sort_order.keys():
-        s903_df = s903_df.sort_values(
-            sort_order[table_name], ascending=False, ignore_index=True
-        )
-    if table_name in dedup.keys():
-        s903_df = s903_df.drop_duplicates(subset=dedup[table_name], keep="first")
+    s903_df = s903_df.sort_values(
+        sort_order[table_name], ascending=False, ignore_index=True
+    )
+    s903_df = s903_df.drop_duplicates(subset=dedup[table_name], keep="first")
     return s903_df
 
 
@@ -82,8 +80,8 @@ def convert_dates(s903_df, dates, table_name):
 
 
 def export_la_file(output, table_name, s903_df):
-    '''
+    """
     Writes the output as a csv
-    '''
+    """
     output_path = Path(output, f"SSDA903_{table_name}_merged.csv")
     s903_df.to_csv(output_path, index=False)
