@@ -7,12 +7,7 @@ from sfdata_stream_parser import events
 
 log = logging.getLogger(__name__)
 
-supported_file_types = [
-    ".xml",
-    ".csv",
-    ".xlsx",
-    ".xlsm"
-]
+supported_file_types = [".xml", ".csv", ".xlsx", ".xlsm"]
 
 
 def flip_dict(some_dict):
@@ -99,6 +94,37 @@ def save_year_error(input, la_log_dir):
         )
 
 
+def check_year(filename):
+    """
+    Check a filename to see if it contains a year, if it does, return that year
+    Expected year formats within string:
+        2022
+        14032021
+        2017-18
+        201819
+
+    :param filename: Filename that probably contains a year
+    :return: Year withing the string
+    """
+    match = re.search(r"(20)\d{2}(.*\d{2})*", filename)
+    if match:
+        try:
+            if len(match.group(2)) == 2:
+                year = match.group(1) + match.group(2)
+                return year
+            if len(match.group(2)) == 3:
+                year = match.group(1) + match.group(2)[1:]
+                return year
+            if len(match.group(2)) == 4:
+                year = match.group(2)
+                return year
+        except TypeError:
+            year = match.group(0)
+            return year
+    else:
+        raise AttributeError
+
+
 def check_file_type(input, file_types, supported_file_types, la_log_dir):
     """
     Check that the correct type of file is being used, e.g. xml. If it is then continue.
@@ -125,8 +151,8 @@ def check_file_type(input, file_types, supported_file_types, la_log_dir):
 
     else:
         with open(
-                f"{Path(la_log_dir, filename)}_error_log_{start_time}.txt",
-                "a",
+            f"{Path(la_log_dir, filename)}_error_log_{start_time}.txt",
+            "a",
         ) as f:
             f.write(
                 f"File: '{filename}{extension}' not in any of the expected formats (csv, xml, xlsx, xlsm)"
